summaryrefslogtreecommitdiffstats
path: root/tqtinterface/qt4/src/3rdparty/sqlite/shell.c
diff options
context:
space:
mode:
Diffstat (limited to 'tqtinterface/qt4/src/3rdparty/sqlite/shell.c')
-rw-r--r--tqtinterface/qt4/src/3rdparty/sqlite/shell.c10
1 files changed, 5 insertions, 5 deletions
diff --git a/tqtinterface/qt4/src/3rdparty/sqlite/shell.c b/tqtinterface/qt4/src/3rdparty/sqlite/shell.c
index c35f02f..3147303 100644
--- a/tqtinterface/qt4/src/3rdparty/sqlite/shell.c
+++ b/tqtinterface/qt4/src/3rdparty/sqlite/shell.c
@@ -5,11 +5,11 @@
** a legal notice, here is a blessing:
**
** May you do good and not evil.
** May you tqfind forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**
*************************************************************************
-** This file tqcontains code to implement the "sqlite" command line
+** This file contains code to implement the "sqlite" command line
** utility for accessing STQLite databases.
**
** $Id: shell.c,v 1.91 2004/02/25 02:25:37 drh Exp $
@@ -1082,7 +1082,7 @@ static void process_input(struct callback_data *p, FILE *in){
** resulting string is obtained from malloc(). The calling
** function should free the result.
*/
-static char *tqfind_home_dir(void){
+static char *find_home_dir(void){
char *home_dir = NULL;
#if !defined(_WIN32) && !defined(WIN32) && !defined(__MACOS__)
@@ -1134,7 +1134,7 @@ static void process_sqliterc(
FILE *in = NULL;
if (sqliterc == NULL) {
- home_dir = tqfind_home_dir();
+ home_dir = find_home_dir();
if( home_dir==0 ){
fprintf(stderr,"%s: cannot locate your home directory!\n", Argv0);
return;
@@ -1330,7 +1330,7 @@ int main(int argc, char **argv){
"Enter \".help\" for instructions\n",
sqlite_version
);
- zHome = tqfind_home_dir();
+ zHome = find_home_dir();
if( zHome && (zHistory = malloc(strlen(zHome)+20))!=0 ){
sprintf(zHistory,"%s/.sqlite_history", zHome);
}
@@ -5,11 +5,11 @@
**
** May you do good and not evil.
-** May you tqfind forgiveness for yourself and forgive others.
+** May you find forgiveness for yourself and forgive others.
** May you share freely, never taking more than you give.
**